@@ -1,12 +1,12 @@
 package Class::Type::Enum;
 # ABSTRACT: Build Enum-like classes
-$Class::Type::Enum::VERSION = '0.002';
+$Class::Type::Enum::VERSION = '0.003';
 
 use strict;
 use warnings;
 
 use Function::Parameters ':strict';
-use List::Util v1.33 ();
+use List::Util v1.33;
 use Scalar::Util qw(blessed);
 use Class::Method::Modifiers qw(install_modifier);
 
@@ -159,7 +159,7 @@ Class::Type::Enum - Build Enum-like classes
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -172,8 +172,12 @@ version 0.002
 
     has status => (
       is     => 'rw',
-      isa    => Toast::Status->get_test,
-      coerce => Toast::Status->get_coerce,
+      coerce => sub {
+        Toast::Status->coerce_symbol(shift)
+      },
+      isa    => sub {
+        $_[0]->isa('Toast::Status') or die "Toast calamity!"
+      },
     );
   }
 
